<?php
/**
 * Test for the LoginManager class
 * ===============================
 *
 * This example sets up an authorization system using the LoginManager
 * class. You don't have to use this to use the LiveUser class(es), but
 * this way you don't need to take care of the login-process, storing
 * the user object in a session and more...
 *
 * This example is intended to be used with the auth XML driver.
 * No permission management is supported.
 *
 * @author Bjrn Kraus <krausbn@php.net>
 * @version $Id: example.php,v 1.4 2003/07/23 20:51:32 mw21st Exp $
 **/
error_reporting(E_ALL);

// Get LiveUser configuration array
require_once('conf.php');

// Get LoginManager class definition
require_once 'LiveUser/LiveUser.php';

// The error handling stuff is not needed and used only for debugging
// while LiveUser is not yet mature
PEAR::setErrorHandling(PEAR_ERROR_CALLBACK, 'eHandler');

function eHandler($errObj)
{
    echo('<hr><font color=red>'.$errObj->getMessage().':<br>'.$errObj->getUserinfo().'</font><hr>');
}


// Create new LiveUser (LoginManager) object.
// Well only use the auth container, permissions are not used.
$LU = LiveUser::factory($liveuserConfig);

// This sets a callback function if the user hasn't logged in yet
$LU->setLoginFunction('testLogin');

// This sets a callback function when the user tries to logout.
// In our case it's ok to use the same function.
$LU->setLogoutFunction('testLogin');

/**
 * Example callback function on logging in
 */
function testLogin()
{
    header('Location: loginscreen.php?target=example.php');
    exit();
} // end func testLogin

// Trigger the login process
$LU->init();
?>
<html>
<head>
<title>Example 1</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
</head>

<body bgcolor="#FFFFFF">
<?php
// Check if the user has logged in successfully
if (!$LU->isLoggedIn()) {
    // The user couldn't login, so let's check if the reason was that
    // he's not yet been declared "valid" by an administrator.
    if ($LU->isInactive()) {
        echo "<h3>Sorry kid, but one of our admins has yet to approve ";
        echo "your user status. Please be patient. Don't call us - ";
        echo "we'll call you.</h3>";
    } else {
        echo "<h3>Sorry, we can't let you in. Check if the spelling of ";
        echo "your handle and password is correct.</h3>";
    }
    echo '<p>&nbsp;</p>';
    echo '<p><i>Login Data for this Example:</i></p>';
    echo '<table border="1">';
    echo '  <tr>';
    echo '    <th width="100">Handle</th>';
    echo '    <th width="100">Password</th>';
    echo '  </tr>';
    echo '  <tr>';
    echo '    <td width="100">father</td>';
    echo '    <td width="100">father</td>';
    echo '  </tr>';
    echo '  <tr>';
    echo '    <td width="100">mother</td>';
    echo '    <td width="100">mother</td>';
    echo '  </tr>';
    echo '  <tr>';
    echo '    <td width="100">child</td>';
    echo '    <td width="100">child</td>';
    echo '  </tr>';
    echo '</table>';
} else {
    // Okay, he's in.
    echo '<h2 align="center">User logged in: '.$LU->getHandle().'</h2>';
    echo "<h3>Congrats, you're in</h3>";
}

// Show logout link.
echo '<p align="center"><a href="example.php?logout=1">Logout</a></p>';

// Just some more debug output with no further relevance
echo '<hr><pre>';
print_r($LU);
echo '<hr>';
print_r($_SESSION);
echo '<hr>';
print_r($_POST);
echo '</pre>';

echo '<br>Handle:';
print_r($LU->getHandle());
echo '<br>User Type:';
print_r($LU->getProperty('userType'));
?>
</body>
</html>